@@ -54,6 +54,11 @@ if FOAM_BRANCH_VERSION( "dev", ">=", "010600" ):
     from icoFlux.r1_6_dev import *
     pass
 
+
+#--------------------------------------------------------------------------------------
+if FOAM_REF_VERSION( ">=", "020000" ):
+    from icoFlux.r2_0_0 import *
+    pass
     
 #--------------------------------------------------------------------------------------
 def entry_point():
