@@ -43,7 +43,7 @@ class solver( object ):
         from Foam.OpenFOAM import ext_Info, nl
         ext_Info() << "Time = " << self.runTime.timeName() << nl << nl
         
-        piso, nCorr, nNonOrthCorr, momentumPredictor, transonic, nOuterCorr = getPISOControls( self.mesh )
+        piso, nCorr, nNonOrthCorr, momentumPredictor, transSonic, nOuterCorr = getPISOControls( self.mesh )
 
         from Foam.finiteVolume.cfdTools.incompressible import CourantNo
         CoNum, meanCoNum = CourantNo( self.mesh, self.phi, self.runTime )
@@ -194,14 +194,15 @@ def main_standalone( argc, argv ):
     from Foam.OpenFOAM import ext_Info, nl
     ext_Info() << "\nStarting time loop\n"
 
-    while runTime.loop() :
+    runTime.increment()
+    while not runTime.end() :
         ext_Info() << "Time = " <<  runTime.timeName() << nl << nl
 
         from Foam.finiteVolume.cfdTools.general.include import readPISOControls
-        piso, nCorr, nNonOrthCorr, momentumPredictor, transonic, nOuterCorr = readPISOControls( mesh )
+        piso, nCorr, nNonOrthCorr, momentumPredictor, transonic, nOuterCorr, ddtPhiCorr = readPISOControls( mesh )
 
         from Foam.finiteVolume.cfdTools.incompressible import CourantNo
-        CoNum, meanCoNum, velMag = CourantNo( mesh, phi, runTime )
+        CoNum, meanCoNum = CourantNo( mesh, phi, runTime )
 
         from Foam import fvm
         UEqn = ( fvm.ddt( U ) + fvm.div( phi, U ) - fvm.laplacian( nu, U ) )
@@ -246,6 +247,7 @@ def main_standalone( argc, argv ):
         ext_Info() << "ExecutionTime = " << runTime.elapsedCpuTime() << " s" << \
                       "  ClockTime = " << runTime.elapsedClockTime() << " s" << nl << nl
 
+        runTime.increment()
         pass
 
     ext_Info() << "End\n"
@@ -255,18 +257,18 @@ def main_standalone( argc, argv ):
 
     
 #--------------------------------------------------------------------------------------
-from Foam import FOAM_BRANCH_VERSION
-if FOAM_BRANCH_VERSION( "dev", ">=", "010600" ):
+from Foam import FOAM_REF_VERSION
+if FOAM_REF_VERSION( "==", "010500" ):
    if __name__ == "__main__" :
-      import sys, os
+      import os,sys
       argv = sys.argv
       os._exit( main_standalone( len( argv ), argv ) )
       pass
    pass
 else:
    from Foam.OpenFOAM import ext_Info
-   ext_Info()<< "\nTo use this solver, It is necessary to SWIG OpenFoam1.6 \n "     
-    
+   ext_Info()<< "\nTo use this solver, It is necessary to SWIG OpenFoam1.5 \n "     
+
     
 #--------------------------------------------------------------------------------------
 
